from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNPostalAddressFormatter(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Contacts.CNPostalAddressFormatterStyle)

    @min_os_level("10.11")
    def testConstants(self):
        self.assertEqual(Contacts.CNPostalAddressFormatterStyleMailingAddress, 0)
        self.assertIsInstance(Contacts.CNPostalAddressPropertyAttribute, str)
        self.assertIsInstance(
            Contacts.CNPostalAddressLocalizedPropertyNameAttribute, str
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNInstantMessageAddress(TestCase):
    @min_os_level("10.11")
    def testConstants(self):
        self.assertIsInstance(Contacts.CNInstantMessageAddressUsernameKey, str)
        self.assertIsInstance(Contacts.CNInstantMessageAddressServiceKey, str)
        self.assertIsInstance(Contacts.CNInstantMessageServiceAIM, str)
        self.assertIsInstance(Contacts.CNInstantMessageServiceFacebook, str)
        self.assertIsInstance(Contacts.CNInstantMessageServiceGaduGadu, str)
        self.assertIsInstance(Contacts.CNInstantMessageServiceGoogleTalk, str)
        self.assertIsInstance(Contacts.CNInstantMessageServiceICQ, str)
        self.assertIsInstance(Contacts.CNInstantMessageServiceJabber, str)
        self.assertIsInstance(Contacts.CNInstantMessageServiceMSN, str)
        self.assertIsInstance(Contacts.CNInstantMessageServiceQQ, str)
        self.assertIsInstance(Contacts.CNInstantMessageServiceSkype, str)
        self.assertIsInstance(Contacts.CNInstantMessageServiceYahoo, str)



"""
Python mapping for the Contacts framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from Contacts import _metadata
from Contacts import _Contacts

sys.modules["Contacts"] = mod = objc.ObjCLazyModule(
    "Contacts",
    "com.apple.Contacts.framework",
    objc.pathForFramework("/System/Library/Frameworks/Contacts.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_Contacts, Foundation),
)


del sys.modules["Contacts._metadata"]



#!/usr/bin/env python3
"""
Script for dumping contacts
"""

import Contacts


def print_info(contact, stop):
    if contact.isKeyAvailable_(Contacts.CNContactEmailAddressesKey):
        print(", ".join(val.value() for val in contact.emailAddresses()))
    else:
        print("Contact without e-mail")
    return False


def main():
    fetchRequest = Contacts.CNContactFetchRequest.alloc().initWithKeysToFetch_(
        [Contacts.CNContactEmailAddressesKey]
    )

    store = Contacts.CNContactStore.alloc().init()
    ok, error = store.enumerateContactsWithFetchRequest_error_usingBlock_(
        fetchRequest, None, print_info
    )
    if not ok:
        print("Fetching contacts failed", error)


if __name__ == "__main__":
    main()



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNContactRelation(TestCase):
    @min_os_level("10.11")
    def testConstants10_11(self):
        self.assertIsInstance(Contacts.CNLabelContactRelationFather, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationMother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationParent, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationBrother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationSister, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationChild, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationFriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationSpouse, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationPartner, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationAssistant, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationManager, str)

    @min_os_level("10.13")
    def testConstants10_13(self):
        self.assertIsInstance(Contacts.CNLabelContactRelationSon, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationDaughter, str)

    @min_os_level("10.15")
    def testConstants10_15(self):
        self.assertIsInstance(Contacts.CNLabelContactRelationColleague, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationTeacher, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationSibling, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungerSibling, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationElderSibling, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungerSister, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungestSister, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationElderSister, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationEldestSister, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungerBrother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungestBrother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationElderBrother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationEldestBrother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationMaleFriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationFemaleFriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationWife, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationHusband, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationMalePartner, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationFemalePartner, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGirlfriendOrBoyfriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGirlfriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationBoyfriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandparent, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandmother, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandmotherMothersMother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandmotherFathersMother, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandfather, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandfatherMothersFather, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandfatherFathersFather, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationGreatGrandparent, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGreatGrandmother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGreatGrandfather, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandchild, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGranddaughter, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGranddaughterDaughtersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGranddaughterSonsDaughter, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandson, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandsonDaughtersSon, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandsonSonsSon, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGreatGrandchild, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGreatGranddaughter, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGreatGrandson, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationParentInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationMotherInLaw, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationMotherInLawWifesMother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationMotherInLawHusbandsMother, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationFatherInLaw, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationFatherInLawWifesFather, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationFatherInLawHusbandsFather, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationCoParentInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationCoMotherInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationCoFatherInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationSiblingInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungerSiblingInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationElderSiblingInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationSisterInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungerSisterInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationElderSisterInLaw, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationSisterInLawSpousesSister, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationSisterInLawWifesSister, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationSisterInLawHusbandsSister, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationSisterInLawBrothersWife, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationSisterInLawYoungerBrothersWife, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationSisterInLawElderBrothersWife, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungerBrother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungestBrother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationElderBrother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationEldestBrother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationMaleFriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationFemaleFriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationWife, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationHusband, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationMalePartner, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationFemalePartner, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGirlfriendOrBoyfriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGirlfriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationBoyfriend, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandparent, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandmother, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandmotherMothersMother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandmotherFathersMother, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandfather, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandfatherMothersFather, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandfatherFathersFather, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationGreatGrandparent, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGreatGrandmother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGreatGrandfather, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationBrotherInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungerBrotherInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationElderBrotherInLaw, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationBrotherInLawSpousesBrother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationBrotherInLawHusbandsBrother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationBrotherInLawWifesBrother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationBrotherInLawSistersHusband, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationBrotherInLawYoungerSistersHusband, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationBrotherInLawElderSistersHusband, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationSisterInLawWifesBrothersWife, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationSisterInLawHusbandsBrothersWife, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationBrotherInLawWifesSistersHusband, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationBrotherInLawHusbandsSistersHusband, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationCoSiblingInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationCoSisterInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationCoBrotherInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationChildInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationDaughterInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationSonInLaw, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationCousin, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationYoungerCousin, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationElderCousin, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationMaleCousin, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationFemaleCousin, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinParentsSiblingsChild, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinParentsSiblingsSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinParentsSiblingsSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinParentsSiblingsSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinParentsSiblingsDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinParentsSiblingsDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinParentsSiblingsDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinMothersSistersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinMothersSistersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinMothersSistersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinMothersSistersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinMothersSistersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinMothersSistersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinMothersBrothersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinMothersBrothersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinMothersBrothersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinMothersBrothersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinMothersBrothersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinMothersBrothersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinFathersSistersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinFathersSistersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinFathersSistersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinFathersSistersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinFathersSistersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinFathersSistersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinFathersBrothersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinFathersBrothersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinFathersBrothersDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinFathersBrothersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinFathersBrothersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinFathersBrothersSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinGrandparentsSiblingsChild, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinGrandparentsSiblingsDaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationCousinGrandparentsSiblingsSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinMothersSiblingsSonOrFathersSistersSon,  # noqa: B950
            str,
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinMothersSiblingsSonOrFathersSistersSon,
            str,
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationYoungerCousinMothersSiblingsDaughterOrFathersSistersDaughter,  # noqa: B950
            str,
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationElderCousinMothersSiblingsDaughterOrFathersSistersDaughter,  # noqa: B950
            str,
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationParentsSibling, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationParentsYoungerSibling, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationParentsElderSibling, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationParentsSiblingMothersSibling, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationParentsSiblingMothersYoungerSibling, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationParentsSiblingMothersElderSibling, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationParentsSiblingFathersSibling, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationParentsSiblingFathersYoungerSibling, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationParentsSiblingFathersElderSibling, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationAunt, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationAuntParentsSister, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationAuntParentsYoungerSister, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationAuntParentsElderSister, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationAuntFathersSister, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationAuntFathersYoungerSister, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationAuntFathersElderSister, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationAuntFathersBrothersWife, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationAuntFathersYoungerBrothersWife, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationAuntFathersElderBrothersWife, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationAuntMothersSister, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationAuntMothersYoungerSister, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationAuntMothersElderSister, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationAuntMothersBrothersWife, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandaunt, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationUncle, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationUncleParentsBrother, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationUncleParentsYoungerBrother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationUncleParentsElderBrother, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationUncleMothersBrother, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationUncleMothersYoungerBrother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationUncleMothersElderBrother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationUncleMothersSistersHusband, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationUncleFathersBrother, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationUncleFathersYoungerBrother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationUncleFathersElderBrother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationUncleFathersSistersHusband, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationUncleFathersYoungerSistersHusband, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationUncleFathersElderSistersHusband, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationGranduncle, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationSiblingsChild, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationNiece, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationNieceSistersDaughter, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationNieceBrothersDaughter, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationNieceSistersDaughterOrWifesSiblingsDaughter,
            str,
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationNieceBrothersDaughterOrHusbandsSiblingsDaughter,
            str,
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationNephew, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationNephewSistersSon, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationNephewBrothersSon, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationNephewBrothersSonOrHusbandsSiblingsSon, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationNephewSistersSonOrWifesSiblingsSon, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandniece, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandnieceSistersGranddaughter, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandnieceBrothersGranddaughter, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandnephew, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandnephewSistersGrandson, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandnephewBrothersGrandson, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationStepparent, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationStepfather, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationStepmother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationStepchild, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationStepson, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationStepdaughter, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationStepbrother, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationStepsister, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationMotherInLawOrStepmother, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationFatherInLawOrStepfather, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationDaughterInLawOrStepdaughter, str
        )
        self.assertIsInstance(Contacts.CNLabelContactRelationSonInLawOrStepson, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationCousinOrSiblingsChild, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationNieceOrCousin, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationNephewOrCousin, str)
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGrandchildOrSiblingsChild, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationGreatGrandchildOrSiblingsGrandchild, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationDaughterInLawOrSisterInLaw, str
        )
        self.assertIsInstance(
            Contacts.CNLabelContactRelationSonInLawOrBrotherInLaw, str
        )

    @min_os_level("11.0")
    def testConstants11_0(self):
        self.assertIsInstance(Contacts.CNLabelContactRelationGranddaughterOrNiece, str)
        self.assertIsInstance(Contacts.CNLabelContactRelationGrandsonOrNephew, str)



import Contacts
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCNContact(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Contacts.CNContactSortOrder)
        self.assertIsEnumType(Contacts.CNContactType)

    @min_os_level("10.12")
    def testConstants10_12(self):
        self.assertIsInstance(Contacts.CNContactPhoneticOrganizationNameKey, str)
        self.assertIsInstance(Contacts.CNContactImageDataAvailableKey, str)

    @min_os_level("10.11")
    def testConstants(self):
        self.assertEqual(Contacts.CNContactTypePerson, 0)
        self.assertEqual(Contacts.CNContactTypeOrganization, 1)

        self.assertEqual(Contacts.CNContactSortOrderNone, 0)
        self.assertEqual(Contacts.CNContactSortOrderUserDefault, 1)
        self.assertEqual(Contacts.CNContactSortOrderGivenName, 2)
        self.assertEqual(Contacts.CNContactSortOrderFamilyName, 3)

        self.assertIsInstance(Contacts.CNContactPropertyNotFetchedExceptionName, str)
        self.assertIsInstance(Contacts.CNContactIdentifierKey, str)
        self.assertIsInstance(Contacts.CNContactNamePrefixKey, str)
        self.assertIsInstance(Contacts.CNContactGivenNameKey, str)
        self.assertIsInstance(Contacts.CNContactMiddleNameKey, str)
        self.assertIsInstance(Contacts.CNContactFamilyNameKey, str)
        self.assertIsInstance(Contacts.CNContactPreviousFamilyNameKey, str)
        self.assertIsInstance(Contacts.CNContactNameSuffixKey, str)
        self.assertIsInstance(Contacts.CNContactNicknameKey, str)
        self.assertIsInstance(Contacts.CNContactPhoneticGivenNameKey, str)
        self.assertIsInstance(Contacts.CNContactPhoneticMiddleNameKey, str)
        self.assertIsInstance(Contacts.CNContactPhoneticFamilyNameKey, str)
        self.assertIsInstance(Contacts.CNContactOrganizationNameKey, str)
        self.assertIsInstance(Contacts.CNContactDepartmentNameKey, str)
        self.assertIsInstance(Contacts.CNContactJobTitleKey, str)
        self.assertIsInstance(Contacts.CNContactBirthdayKey, str)
        self.assertIsInstance(Contacts.CNContactNonGregorianBirthdayKey, str)
        self.assertIsInstance(Contacts.CNContactNoteKey, str)
        self.assertIsInstance(Contacts.CNContactImageDataKey, str)
        self.assertIsInstance(Contacts.CNContactThumbnailImageDataKey, str)
        self.assertIsInstance(Contacts.CNContactTypeKey, str)
        self.assertIsInstance(Contacts.CNContactPhoneNumbersKey, str)
        self.assertIsInstance(Contacts.CNContactEmailAddressesKey, str)
        self.assertIsInstance(Contacts.CNContactPostalAddressesKey, str)
        self.assertIsInstance(Contacts.CNContactDatesKey, str)
        self.assertIsInstance(Contacts.CNContactUrlAddressesKey, str)
        self.assertIsInstance(Contacts.CNContactRelationsKey, str)
        self.assertIsInstance(Contacts.CNContactSocialProfilesKey, str)
        self.assertIsInstance(Contacts.CNContactInstantMessageAddressesKey, str)

    @min_os_level("10.11")
    def testProtocols(self):
        self.assertProtocolExists("CNKeyDescriptor")

    @min_os_level("10.11")
    def testMethods(self):
        self.assertResultIsBOOL(Contacts.CNContact.isKeyAvailable_)
        self.assertResultIsBOOL(Contacts.CNContact.areKeysAvailable_)
        self.assertResultIsBOOL(Contacts.CNContact.isUnifiedWithContactWithIdentifier_)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts  # noqa: F401


class TestCNChangeHistoryEvent(TestCase):
    @min_os_level("10.15")
    def testProtocols(self):
        self.assertProtocolExists("CNChangeHistoryEventVisitor")



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNChangeHistoryFetchRequest(TestCase):
    @min_os_level("10.15")
    def testProtocols(self):
        self.assertProtocolExists("CNKeyDescriptor")

    @min_os_level("10.15")
    def test_methods(self):
        self.assertResultIsBOOL(Contacts.CNChangeHistoryFetchRequest.shouldUnifyResults)
        self.assertArgIsBOOL(
            Contacts.CNChangeHistoryFetchRequest.setShouldUnifyResults_, 0
        )

        self.assertResultIsBOOL(Contacts.CNChangeHistoryFetchRequest.mutableObjects)
        self.assertArgIsBOOL(Contacts.CNChangeHistoryFetchRequest.setMutableObjects_, 0)

        self.assertResultIsBOOL(
            Contacts.CNChangeHistoryFetchRequest.includeGroupChanges
        )
        self.assertArgIsBOOL(
            Contacts.CNChangeHistoryFetchRequest.setIncludeGroupChanges_, 0
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNContactFetchRequest(TestCase):
    @min_os_level("10.11")
    def testMethods(self):
        self.assertResultIsBOOL(Contacts.CNContactFetchRequest.mutableObjects)
        self.assertArgIsBOOL(Contacts.CNContactFetchRequest.setMutableObjects_, 0)

        self.assertResultIsBOOL(Contacts.CNContactFetchRequest.unifyResults)
        self.assertArgIsBOOL(Contacts.CNContactFetchRequest.setUnifyResults_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNPhoneNumber(TestCase):
    @min_os_level("10.11")
    def testConstants(self):
        self.assertIsInstance(Contacts.CNLabelPhoneNumberiPhone, str)
        self.assertIsInstance(Contacts.CNLabelPhoneNumberMobile, str)
        self.assertIsInstance(Contacts.CNLabelPhoneNumberMain, str)
        self.assertIsInstance(Contacts.CNLabelPhoneNumberHomeFax, str)
        self.assertIsInstance(Contacts.CNLabelPhoneNumberWorkFax, str)
        self.assertIsInstance(Contacts.CNLabelPhoneNumberOtherFax, str)
        self.assertIsInstance(Contacts.CNLabelPhoneNumberPager, str)

    @min_os_level("11.1")
    def testConstants11_1(self):
        self.assertIsInstance(Contacts.CNLabelPhoneNumberAppleWatch, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNPostalAddress(TestCase):
    @min_os_level("10.11")
    def testConstants(self):
        self.assertIsInstance(Contacts.CNPostalAddressStreetKey, str)
        self.assertIsInstance(Contacts.CNPostalAddressCityKey, str)
        self.assertIsInstance(Contacts.CNPostalAddressStateKey, str)
        self.assertIsInstance(Contacts.CNPostalAddressPostalCodeKey, str)
        self.assertIsInstance(Contacts.CNPostalAddressCountryKey, str)
        self.assertIsInstance(Contacts.CNPostalAddressISOCountryCodeKey, str)

        self.assertIsInstance(Contacts.CNPostalAddressSubLocalityKey, str)
        self.assertIsInstance(Contacts.CNPostalAddressSubAdministrativeAreaKey, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNContactFormatter(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Contacts.CNContactDisplayNameOrder)
        self.assertIsEnumType(Contacts.CNContactFormatterStyle)

    @min_os_level("10.11")
    def testConstants(self):
        self.assertEqual(Contacts.CNContactFormatterStyleFullName, 0)
        self.assertEqual(Contacts.CNContactFormatterStylePhoneticFullName, 1)

        self.assertEqual(Contacts.CNContactDisplayNameOrderUserDefault, 0)
        self.assertEqual(Contacts.CNContactDisplayNameOrderGivenNameFirst, 1)
        self.assertEqual(Contacts.CNContactDisplayNameOrderFamilyNameFirst, 2)

        self.assertIsInstance(Contacts.CNContactPropertyAttribute, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNGroup(TestCase):
    @min_os_level("10.11")
    def testConstants(self):
        self.assertIsInstance(Contacts.CNGroupIdentifierKey, str)
        self.assertIsInstance(Contacts.CNGroupNameKey, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc
import Contacts


class TestCNContactStore(TestCase):
    @min_os_level("10.11")
    def testConstants(self):
        self.assertEqual(Contacts.CNEntityTypeContacts, 0)

        self.assertEqual(Contacts.CNAuthorizationStatusNotDetermined, 0)
        self.assertEqual(Contacts.CNAuthorizationStatusRestricted, 1)
        self.assertEqual(Contacts.CNAuthorizationStatusDenied, 2)
        self.assertEqual(Contacts.CNAuthorizationStatusAuthorized, 3)

    @min_os_level("10.11")
    def testMethods(self):
        self.assertArgIsBlock(
            Contacts.CNContactStore.requestAccessForEntityType_completionHandler_,
            1,
            b"v" + objc._C_NSBOOL + b"@",
        )
        self.assertArgIsOut(
            Contacts.CNContactStore.unifiedContactsMatchingPredicate_keysToFetch_error_,
            2,
        )
        self.assertArgIsOut(
            Contacts.CNContactStore.unifiedContactWithIdentifier_keysToFetch_error_, 2
        )
        self.assertArgIsOut(
            Contacts.CNContactStore.unifiedMeContactWithKeysToFetch_error_, 1
        )

        self.assertResultIsBOOL(
            Contacts.CNContactStore.enumerateContactsWithFetchRequest_error_usingBlock_
        )
        self.assertArgIsOut(
            Contacts.CNContactStore.enumerateContactsWithFetchRequest_error_usingBlock_,
            1,
        )
        self.assertArgIsBlock(
            Contacts.CNContactStore.enumerateContactsWithFetchRequest_error_usingBlock_,
            2,
            b"v@o^Z",
        )

        self.assertArgIsOut(Contacts.CNContactStore.groupsMatchingPredicate_error_, 1)
        self.assertArgIsOut(
            Contacts.CNContactStore.containersMatchingPredicate_error_, 1
        )

        self.assertResultIsBOOL(Contacts.CNContactStore.executeSaveRequest_error_)
        self.assertArgIsOut(Contacts.CNContactStore.executeSaveRequest_error_, 1)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNContactVCardSerialization(TestCase):
    @min_os_level("10.11")
    def testMethods(self):
        self.assertArgIsOut(
            Contacts.CNContactVCardSerialization.dataWithContacts_error_, 1
        )
        self.assertArgIsOut(
            Contacts.CNContactVCardSerialization.contactsWithData_error_, 1
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNContactStore(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Contacts.CNAuthorizationStatus)
        self.assertIsEnumType(Contacts.CNEntityType)

    def test_methods(self):
        self.assertArgIsOut(
            Contacts.CNContactStore.unifiedContactsMatchingPredicate_keysToFetch_error_,
            2,
        )
        self.assertArgIsOut(
            Contacts.CNContactStore.unifiedContactWithIdentifier_keysToFetch_error_, 2
        )
        self.assertArgIsOut(
            Contacts.CNContactStore.unifiedMeContactWithKeysToFetch_error_, 1
        )

        self.assertResultIsBOOL(
            Contacts.CNContactStore.enumerateContactsWithFetchRequest_error_usingBlock_
        )
        self.assertArgIsOut(
            Contacts.CNContactStore.enumerateContactsWithFetchRequest_error_usingBlock_,
            1,
        )
        self.assertArgIsBlock(
            Contacts.CNContactStore.enumerateContactsWithFetchRequest_error_usingBlock_,
            2,
            b"v@o^Z",
        )

        self.assertArgIsOut(Contacts.CNContactStore.groupsMatchingPredicate_error_, 1)
        self.assertArgIsOut(
            Contacts.CNContactStore.containersMatchingPredicate_error_, 1
        )

        self.assertResultIsBOOL(Contacts.CNContactStore.executeSaveRequest_error_)
        self.assertArgIsOut(Contacts.CNContactStore.executeSaveRequest_error_, 1)

    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertArgIsOut(
            Contacts.CNContactStore.enumeratorForContactFetchRequest_error_, 1
        )
        self.assertArgIsOut(
            Contacts.CNContactStore.enumeratorForChangeHistoryFetchRequest_error_, 1
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNError(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Contacts.CNErrorCode)

    @min_os_level("10.11")
    def testConstants(self):
        self.assertIsInstance(Contacts.CNErrorDomain, str)

        self.assertEqual(Contacts.CNErrorCodeCommunicationError, 1)
        self.assertEqual(Contacts.CNErrorCodeDataAccessError, 2)
        self.assertEqual(Contacts.CNErrorCodeAuthorizationDenied, 100)
        self.assertEqual(Contacts.CNErrorCodeNoAccessableWritableContainers, 101)
        self.assertEqual(Contacts.CNErrorCodeUnauthorizedKeys, 102)
        self.assertEqual(Contacts.CNErrorCodeFeatureDisabledByUser, 103)
        self.assertEqual(Contacts.CNErrorCodeRecordDoesNotExist, 200)
        self.assertEqual(Contacts.CNErrorCodeInsertedRecordAlreadyExists, 201)
        self.assertEqual(Contacts.CNErrorCodeContainmentCycle, 202)
        self.assertEqual(Contacts.CNErrorCodeContainmentScope, 203)
        self.assertEqual(Contacts.CNErrorCodeParentRecordDoesNotExist, 204)
        self.assertEqual(Contacts.CNErrorCodeRecordIdentifierInvalid, 205)
        self.assertEqual(Contacts.CNErrorCodeRecordNotWritable, 206)
        self.assertEqual(Contacts.CNErrorCodeParentContainerNotWritable, 207)
        self.assertEqual(Contacts.CNErrorCodeValidationMultipleErrors, 300)
        self.assertEqual(Contacts.CNErrorCodeValidationTypeMismatch, 301)
        self.assertEqual(Contacts.CNErrorCodeValidationConfigurationError, 302)
        self.assertEqual(Contacts.CNErrorCodePredicateInvalid, 400)
        self.assertEqual(Contacts.CNErrorCodePolicyViolation, 500)
        self.assertEqual(Contacts.CNErrorCodeClientIdentifierInvalid, 600)
        self.assertEqual(Contacts.CNErrorCodeClientIdentifierDoesNotExist, 601)
        self.assertEqual(Contacts.CNErrorCodeClientIdentifierCollision, 602)
        self.assertEqual(Contacts.CNErrorCodeChangeHistoryExpired, 603)
        self.assertEqual(Contacts.CNErrorCodeChangeHistoryInvalidAnchor, 604)
        self.assertEqual(Contacts.CNErrorCodeChangeHistoryInvalidFetchRequest, 605)

        self.assertEqual(Contacts.CNErrorCodeVCardMalformed, 700)
        self.assertEqual(Contacts.CNErrorCodeVCardSummarizationError, 701)

        self.assertIsInstance(Contacts.CNErrorUserInfoAffectedRecordsKey, str)
        self.assertIsInstance(Contacts.CNErrorUserInfoAffectedRecordIdentifiersKey, str)
        self.assertIsInstance(Contacts.CNErrorUserInfoValidationErrorsKey, str)
        self.assertIsInstance(Contacts.CNErrorUserInfoKeyPathsKey, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNSaveRequest(TestCase):
    @min_os_level("12.3")
    def testMethods12_3(self):
        self.assertResultIsBOOL(Contacts.CNSaveRequest.shouldRefetchContacts)
        self.assertArgIsBOOL(Contacts.CNSaveRequest.setShouldRefetchContacts_, 0)



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 18:43:34 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$CNContactBirthdayKey$CNContactDatesKey$CNContactDepartmentNameKey$CNContactEmailAddressesKey$CNContactFamilyNameKey$CNContactGivenNameKey$CNContactIdentifierKey$CNContactImageDataAvailableKey$CNContactImageDataKey$CNContactInstantMessageAddressesKey$CNContactJobTitleKey$CNContactMiddleNameKey$CNContactNamePrefixKey$CNContactNameSuffixKey$CNContactNicknameKey$CNContactNonGregorianBirthdayKey$CNContactNoteKey$CNContactOrganizationNameKey$CNContactPhoneNumbersKey$CNContactPhoneticFamilyNameKey$CNContactPhoneticGivenNameKey$CNContactPhoneticMiddleNameKey$CNContactPhoneticOrganizationNameKey$CNContactPostalAddressesKey$CNContactPreviousFamilyNameKey$CNContactPropertyAttribute$CNContactPropertyNotFetchedExceptionName$CNContactRelationsKey$CNContactSocialProfilesKey$CNContactStoreDidChangeNotification$CNContactThumbnailImageDataKey$CNContactTypeKey$CNContactUrlAddressesKey$CNContainerIdentifierKey$CNContainerNameKey$CNContainerTypeKey$CNErrorDomain$CNErrorUserInfoAffectedRecordIdentifiersKey$CNErrorUserInfoAffectedRecordsKey$CNErrorUserInfoKeyPathsKey$CNErrorUserInfoValidationErrorsKey$CNGroupIdentifierKey$CNGroupNameKey$CNInstantMessageAddressServiceKey$CNInstantMessageAddressUsernameKey$CNInstantMessageServiceAIM$CNInstantMessageServiceFacebook$CNInstantMessageServiceGaduGadu$CNInstantMessageServiceGoogleTalk$CNInstantMessageServiceICQ$CNInstantMessageServiceJabber$CNInstantMessageServiceMSN$CNInstantMessageServiceQQ$CNInstantMessageServiceSkype$CNInstantMessageServiceYahoo$CNLabelContactRelationAssistant$CNLabelContactRelationAunt$CNLabelContactRelationAuntFathersBrothersWife$CNLabelContactRelationAuntFathersElderBrothersWife$CNLabelContactRelationAuntFathersElderSister$CNLabelContactRelationAuntFathersSister$CNLabelContactRelationAuntFathersYoungerBrothersWife$CNLabelContactRelationAuntFathersYoungerSister$CNLabelContactRelationAuntMothersBrothersWife$CNLabelContactRelationAuntMothersElderSister$CNLabelContactRelationAuntMothersSister$CNLabelContactRelationAuntMothersYoungerSister$CNLabelContactRelationAuntParentsElderSister$CNLabelContactRelationAuntParentsSister$CNLabelContactRelationAuntParentsYoungerSister$CNLabelContactRelationBoyfriend$CNLabelContactRelationBrother$CNLabelContactRelationBrotherInLaw$CNLabelContactRelationBrotherInLawElderSistersHusband$CNLabelContactRelationBrotherInLawHusbandsBrother$CNLabelContactRelationBrotherInLawHusbandsSistersHusband$CNLabelContactRelationBrotherInLawSistersHusband$CNLabelContactRelationBrotherInLawSpousesBrother$CNLabelContactRelationBrotherInLawWifesBrother$CNLabelContactRelationBrotherInLawWifesSistersHusband$CNLabelContactRelationBrotherInLawYoungerSistersHusband$CNLabelContactRelationChild$CNLabelContactRelationChildInLaw$CNLabelContactRelationCoBrotherInLaw$CNLabelContactRelationCoFatherInLaw$CNLabelContactRelationCoMotherInLaw$CNLabelContactRelationCoParentInLaw$CNLabelContactRelationCoSiblingInLaw$CNLabelContactRelationCoSisterInLaw$CNLabelContactRelationColleague$CNLabelContactRelationCousin$CNLabelContactRelationCousinFathersBrothersDaughter$CNLabelContactRelationCousinFathersBrothersSon$CNLabelContactRelationCousinFathersSistersDaughter$CNLabelContactRelationCousinFathersSistersSon$CNLabelContactRelationCousinGrandparentsSiblingsChild$CNLabelContactRelationCousinGrandparentsSiblingsDaughter$CNLabelContactRelationCousinGrandparentsSiblingsSon$CNLabelContactRelationCousinMothersBrothersDaughter$CNLabelContactRelationCousinMothersBrothersSon$CNLabelContactRelationCousinMothersSistersDaughter$CNLabelContactRelationCousinMothersSistersSon$CNLabelContactRelationCousinOrSiblingsChild$CNLabelContactRelationCousinParentsSiblingsChild$CNLabelContactRelationCousinParentsSiblingsDaughter$CNLabelContactRelationCousinParentsSiblingsSon$CNLabelContactRelationDaughter$CNLabelContactRelationDaughterInLaw$CNLabelContactRelationDaughterInLawOrSisterInLaw$CNLabelContactRelationDaughterInLawOrStepdaughter$CNLabelContactRelationElderBrother$CNLabelContactRelationElderBrotherInLaw$CNLabelContactRelationElderCousin$CNLabelContactRelationElderCousinFathersBrothersDaughter$CNLabelContactRelationElderCousinFathersBrothersSon$CNLabelContactRelationElderCousinFathersSistersDaughter$CNLabelContactRelationElderCousinFathersSistersSon$CNLabelContactRelationElderCousinMothersBrothersDaughter$CNLabelContactRelationElderCousinMothersBrothersSon$CNLabelContactRelationElderCousinMothersSiblingsDaughterOrFathersSistersDaughter$CNLabelContactRelationElderCousinMothersSiblingsSonOrFathersSistersSon$CNLabelContactRelationElderCousinMothersSistersDaughter$CNLabelContactRelationElderCousinMothersSistersSon$CNLabelContactRelationElderCousinParentsSiblingsDaughter$CNLabelContactRelationElderCousinParentsSiblingsSon$CNLabelContactRelationElderSibling$CNLabelContactRelationElderSiblingInLaw$CNLabelContactRelationElderSister$CNLabelContactRelationElderSisterInLaw$CNLabelContactRelationEldestBrother$CNLabelContactRelationEldestSister$CNLabelContactRelationFather$CNLabelContactRelationFatherInLaw$CNLabelContactRelationFatherInLawHusbandsFather$CNLabelContactRelationFatherInLawOrStepfather$CNLabelContactRelationFatherInLawWifesFather$CNLabelContactRelationFemaleCousin$CNLabelContactRelationFemaleFriend$CNLabelContactRelationFemalePartner$CNLabelContactRelationFriend$CNLabelContactRelationGirlfriend$CNLabelContactRelationGirlfriendOrBoyfriend$CNLabelContactRelationGrandaunt$CNLabelContactRelationGrandchild$CNLabelContactRelationGrandchildOrSiblingsChild$CNLabelContactRelationGranddaughter$CNLabelContactRelationGranddaughterDaughtersDaughter$CNLabelContactRelationGranddaughterOrNiece$CNLabelContactRelationGranddaughterSonsDaughter$CNLabelContactRelationGrandfather$CNLabelContactRelationGrandfatherFathersFather$CNLabelContactRelationGrandfatherMothersFather$CNLabelContactRelationGrandmother$CNLabelContactRelationGrandmotherFathersMother$CNLabelContactRelationGrandmotherMothersMother$CNLabelContactRelationGrandnephew$CNLabelContactRelationGrandnephewBrothersGrandson$CNLabelContactRelationGrandnephewSistersGrandson$CNLabelContactRelationGrandniece$CNLabelContactRelationGrandnieceBrothersGranddaughter$CNLabelContactRelationGrandnieceSistersGranddaughter$CNLabelContactRelationGrandparent$CNLabelContactRelationGrandson$CNLabelContactRelationGrandsonDaughtersSon$CNLabelContactRelationGrandsonOrNephew$CNLabelContactRelationGrandsonSonsSon$CNLabelContactRelationGranduncle$CNLabelContactRelationGreatGrandchild$CNLabelContactRelationGreatGrandchildOrSiblingsGrandchild$CNLabelContactRelationGreatGranddaughter$CNLabelContactRelationGreatGrandfather$CNLabelContactRelationGreatGrandmother$CNLabelContactRelationGreatGrandparent$CNLabelContactRelationGreatGrandson$CNLabelContactRelationHusband$CNLabelContactRelationMaleCousin$CNLabelContactRelationMaleFriend$CNLabelContactRelationMalePartner$CNLabelContactRelationManager$CNLabelContactRelationMother$CNLabelContactRelationMotherInLaw$CNLabelContactRelationMotherInLawHusbandsMother$CNLabelContactRelationMotherInLawOrStepmother$CNLabelContactRelationMotherInLawWifesMother$CNLabelContactRelationNephew$CNLabelContactRelationNephewBrothersSon$CNLabelContactRelationNephewBrothersSonOrHusbandsSiblingsSon$CNLabelContactRelationNephewOrCousin$CNLabelContactRelationNephewSistersSon$CNLabelContactRelationNephewSistersSonOrWifesSiblingsSon$CNLabelContactRelationNiece$CNLabelContactRelationNieceBrothersDaughter$CNLabelContactRelationNieceBrothersDaughterOrHusbandsSiblingsDaughter$CNLabelContactRelationNieceOrCousin$CNLabelContactRelationNieceSistersDaughter$CNLabelContactRelationNieceSistersDaughterOrWifesSiblingsDaughter$CNLabelContactRelationParent$CNLabelContactRelationParentInLaw$CNLabelContactRelationParentsElderSibling$CNLabelContactRelationParentsSibling$CNLabelContactRelationParentsSiblingFathersElderSibling$CNLabelContactRelationParentsSiblingFathersSibling$CNLabelContactRelationParentsSiblingFathersYoungerSibling$CNLabelContactRelationParentsSiblingMothersElderSibling$CNLabelContactRelationParentsSiblingMothersSibling$CNLabelContactRelationParentsSiblingMothersYoungerSibling$CNLabelContactRelationParentsYoungerSibling$CNLabelContactRelationPartner$CNLabelContactRelationSibling$CNLabelContactRelationSiblingInLaw$CNLabelContactRelationSiblingsChild$CNLabelContactRelationSister$CNLabelContactRelationSisterInLaw$CNLabelContactRelationSisterInLawBrothersWife$CNLabelContactRelationSisterInLawElderBrothersWife$CNLabelContactRelationSisterInLawHusbandsBrothersWife$CNLabelContactRelationSisterInLawHusbandsSister$CNLabelContactRelationSisterInLawSpousesSister$CNLabelContactRelationSisterInLawWifesBrothersWife$CNLabelContactRelationSisterInLawWifesSister$CNLabelContactRelationSisterInLawYoungerBrothersWife$CNLabelContactRelationSon$CNLabelContactRelationSonInLaw$CNLabelContactRelationSonInLawOrBrotherInLaw$CNLabelContactRelationSonInLawOrStepson$CNLabelContactRelationSpouse$CNLabelContactRelationStepbrother$CNLabelContactRelationStepchild$CNLabelContactRelationStepdaughter$CNLabelContactRelationStepfather$CNLabelContactRelationStepmother$CNLabelContactRelationStepparent$CNLabelContactRelationStepsister$CNLabelContactRelationStepson$CNLabelContactRelationTeacher$CNLabelContactRelationUncle$CNLabelContactRelationUncleFathersBrother$CNLabelContactRelationUncleFathersElderBrother$CNLabelContactRelationUncleFathersElderSistersHusband$CNLabelContactRelationUncleFathersSistersHusband$CNLabelContactRelationUncleFathersYoungerBrother$CNLabelContactRelationUncleFathersYoungerSistersHusband$CNLabelContactRelationUncleMothersBrother$CNLabelContactRelationUncleMothersElderBrother$CNLabelContactRelationUncleMothersSistersHusband$CNLabelContactRelationUncleMothersYoungerBrother$CNLabelContactRelationUncleParentsBrother$CNLabelContactRelationUncleParentsElderBrother$CNLabelContactRelationUncleParentsYoungerBrother$CNLabelContactRelationWife$CNLabelContactRelationYoungerBrother$CNLabelContactRelationYoungerBrotherInLaw$CNLabelContactRelationYoungerCousin$CNLabelContactRelationYoungerCousinFathersBrothersDaughter$CNLabelContactRelationYoungerCousinFathersBrothersSon$CNLabelContactRelationYoungerCousinFathersSistersDaughter$CNLabelContactRelationYoungerCousinFathersSistersSon$CNLabelContactRelationYoungerCousinMothersBrothersDaughter$CNLabelContactRelationYoungerCousinMothersBrothersSon$CNLabelContactRelationYoungerCousinMothersSiblingsDaughterOrFathersSistersDaughter$CNLabelContactRelationYoungerCousinMothersSiblingsSonOrFathersSistersSon$CNLabelContactRelationYoungerCousinMothersSistersDaughter$CNLabelContactRelationYoungerCousinMothersSistersSon$CNLabelContactRelationYoungerCousinParentsSiblingsDaughter$CNLabelContactRelationYoungerCousinParentsSiblingsSon$CNLabelContactRelationYoungerSibling$CNLabelContactRelationYoungerSiblingInLaw$CNLabelContactRelationYoungerSister$CNLabelContactRelationYoungerSisterInLaw$CNLabelContactRelationYoungestBrother$CNLabelContactRelationYoungestSister$CNLabelDateAnniversary$CNLabelEmailiCloud$CNLabelHome$CNLabelOther$CNLabelPhoneNumberAppleWatch$CNLabelPhoneNumberHomeFax$CNLabelPhoneNumberMain$CNLabelPhoneNumberMobile$CNLabelPhoneNumberOtherFax$CNLabelPhoneNumberPager$CNLabelPhoneNumberWorkFax$CNLabelPhoneNumberiPhone$CNLabelSchool$CNLabelURLAddressHomePage$CNLabelWork$CNPostalAddressCityKey$CNPostalAddressCountryKey$CNPostalAddressISOCountryCodeKey$CNPostalAddressLocalizedPropertyNameAttribute$CNPostalAddressPostalCodeKey$CNPostalAddressPropertyAttribute$CNPostalAddressStateKey$CNPostalAddressStreetKey$CNPostalAddressSubAdministrativeAreaKey$CNPostalAddressSubLocalityKey$CNSocialProfileServiceFacebook$CNSocialProfileServiceFlickr$CNSocialProfileServiceGameCenter$CNSocialProfileServiceKey$CNSocialProfileServiceLinkedIn$CNSocialProfileServiceMySpace$CNSocialProfileServiceSinaWeibo$CNSocialProfileServiceTencentWeibo$CNSocialProfileServiceTwitter$CNSocialProfileServiceYelp$CNSocialProfileURLStringKey$CNSocialProfileUserIdentifierKey$CNSocialProfileUsernameKey$"""
enums = """$CNAuthorizationStatusAuthorized@3$CNAuthorizationStatusDenied@2$CNAuthorizationStatusNotDetermined@0$CNAuthorizationStatusRestricted@1$CNContactDisplayNameOrderFamilyNameFirst@2$CNContactDisplayNameOrderGivenNameFirst@1$CNContactDisplayNameOrderUserDefault@0$CNContactFormatterStyleFullName@0$CNContactFormatterStylePhoneticFullName@1$CNContactSortOrderFamilyName@3$CNContactSortOrderGivenName@2$CNContactSortOrderNone@0$CNContactSortOrderUserDefault@1$CNContactTypeOrganization@1$CNContactTypePerson@0$CNContainerTypeCardDAV@3$CNContainerTypeExchange@2$CNContainerTypeLocal@1$CNContainerTypeUnassigned@0$CNEntityTypeContacts@0$CNErrorCodeAuthorizationDenied@100$CNErrorCodeChangeHistoryExpired@603$CNErrorCodeChangeHistoryInvalidAnchor@604$CNErrorCodeChangeHistoryInvalidFetchRequest@605$CNErrorCodeClientIdentifierCollision@602$CNErrorCodeClientIdentifierDoesNotExist@601$CNErrorCodeClientIdentifierInvalid@600$CNErrorCodeCommunicationError@1$CNErrorCodeContainmentCycle@202$CNErrorCodeContainmentScope@203$CNErrorCodeDataAccessError@2$CNErrorCodeFeatureDisabledByUser@103$CNErrorCodeInsertedRecordAlreadyExists@201$CNErrorCodeNoAccessableWritableContainers@101$CNErrorCodeParentContainerNotWritable@207$CNErrorCodeParentRecordDoesNotExist@204$CNErrorCodePolicyViolation@500$CNErrorCodePredicateInvalid@400$CNErrorCodeRecordDoesNotExist@200$CNErrorCodeRecordIdentifierInvalid@205$CNErrorCodeRecordNotWritable@206$CNErrorCodeUnauthorizedKeys@102$CNErrorCodeVCardMalformed@700$CNErrorCodeVCardSummarizationError@701$CNErrorCodeValidationConfigurationError@302$CNErrorCodeValidationMultipleErrors@300$CNErrorCodeValidationTypeMismatch@301$CNPostalAddressFormatterStyleMailingAddress@0$"""
misc.update(
    {
        "CNEntityType": NewType("CNEntityType", int),
        "CNContactType": NewType("CNContactType", int),
        "CNContactDisplayNameOrder": NewType("CNContactDisplayNameOrder", int),
        "CNErrorCode": NewType("CNErrorCode", int),
        "CNAuthorizationStatus": NewType("CNAuthorizationStatus", int),
        "CNContactFormatterStyle": NewType("CNContactFormatterStyle", int),
        "CNContactSortOrder": NewType("CNContactSortOrder", int),
        "CNPostalAddressFormatterStyle": NewType("CNPostalAddressFormatterStyle", int),
        "CNContainerType": NewType("CNContainerType", int),
    }
)
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"CNChangeHistoryFetchRequest",
        b"includeGroupChanges",
        {"retval": {"type": b"Z"}},
    )
    r(b"CNChangeHistoryFetchRequest", b"mutableObjects", {"retval": {"type": b"Z"}})
    r(
        b"CNChangeHistoryFetchRequest",
        b"setIncludeGroupChanges:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"CNChangeHistoryFetchRequest",
        b"setMutableObjects:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"CNChangeHistoryFetchRequest",
        b"setShouldUnifyResults:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"CNChangeHistoryFetchRequest", b"shouldUnifyResults", {"retval": {"type": b"Z"}})
    r(b"CNContact", b"areKeysAvailable:", {"retval": {"type": "Z"}})
    r(b"CNContact", b"imageDataAvailable", {"retval": {"type": b"Z"}})
    r(b"CNContact", b"isKeyAvailable:", {"retval": {"type": "Z"}})
    r(b"CNContact", b"isUnifiedWithContactWithIdentifier:", {"retval": {"type": "Z"}})
    r(b"CNContactFetchRequest", b"mutableObjects", {"retval": {"type": "Z"}})
    r(
        b"CNContactFetchRequest",
        b"setMutableObjects:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(b"CNContactFetchRequest", b"setUnifyResults:", {"arguments": {2: {"type": "Z"}}})
    r(b"CNContactFetchRequest", b"unifyResults", {"retval": {"type": "Z"}})
    r(
        b"CNContactStore",
        b"containersMatchingPredicate:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CNContactStore",
        b"enumerateContactsWithFetchRequest:error:usingBlock:",
        {
            "retval": {"type": "Z"},
            "arguments": {
                3: {"type_modifier": b"o"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"o^Z"},
                        },
                    }
                },
            },
        },
    )
    r(
        b"CNContactStore",
        b"enumeratorForChangeHistoryFetchRequest:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CNContactStore",
        b"enumeratorForContactFetchRequest:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CNContactStore",
        b"executeSaveRequest:error:",
        {"retval": {"type": "Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CNContactStore",
        b"groupsMatchingPredicate:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CNContactStore",
        b"requestAccessForEntityType:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"CNContactStore",
        b"unifiedContactWithIdentifier:keysToFetch:error:",
        {"arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"CNContactStore",
        b"unifiedContactsMatchingPredicate:keysToFetch:error:",
        {"arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"CNContactStore",
        b"unifiedMeContactWithKeysToFetch:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CNContactVCardSerialization",
        b"contactsWithData:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"CNContactVCardSerialization",
        b"dataWithContacts:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"CNPhoneNumber", b"init", {"deprecated": 1013})
    r(b"CNPhoneNumber", b"new", {"deprecated": 1013})
    r(
        b"CNSaveRequest",
        b"setShouldRefetchContacts:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"CNSaveRequest", b"shouldRefetchContacts", {"retval": {"type": b"Z"}})
    r(
        b"NSObject",
        b"visitAddContactEvent:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"visitAddGroupEvent:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"visitAddMemberToGroupEvent:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"visitAddSubgroupToGroupEvent:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"visitDeleteContactEvent:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"visitDeleteGroupEvent:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"visitDropEverythingEvent:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"visitRemoveMemberFromGroupEvent:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"visitRemoveSubgroupFromGroupEvent:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"visitUpdateContactEvent:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"visitUpdateGroupEvent:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNSocialProfile(TestCase):
    @min_os_level("10.11")
    def testConstants(self):
        self.assertIsInstance(Contacts.CNSocialProfileURLStringKey, str)
        self.assertIsInstance(Contacts.CNSocialProfileUsernameKey, str)
        self.assertIsInstance(Contacts.CNSocialProfileUserIdentifierKey, str)
        self.assertIsInstance(Contacts.CNSocialProfileServiceKey, str)
        self.assertIsInstance(Contacts.CNSocialProfileServiceFacebook, str)
        self.assertIsInstance(Contacts.CNSocialProfileServiceFlickr, str)
        self.assertIsInstance(Contacts.CNSocialProfileServiceLinkedIn, str)
        self.assertIsInstance(Contacts.CNSocialProfileServiceMySpace, str)
        self.assertIsInstance(Contacts.CNSocialProfileServiceSinaWeibo, str)
        self.assertIsInstance(Contacts.CNSocialProfileServiceTencentWeibo, str)
        self.assertIsInstance(Contacts.CNSocialProfileServiceTwitter, str)
        self.assertIsInstance(Contacts.CNSocialProfileServiceYelp, str)
        self.assertIsInstance(Contacts.CNSocialProfileServiceGameCenter, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNLabeledValue(TestCase):
    @min_os_level("10.11")
    def testConstants(self):
        self.assertIsInstance(Contacts.CNLabelHome, str)
        self.assertIsInstance(Contacts.CNLabelWork, str)
        self.assertIsInstance(Contacts.CNLabelOther, str)
        self.assertIsInstance(Contacts.CNLabelEmailiCloud, str)
        self.assertIsInstance(Contacts.CNLabelURLAddressHomePage, str)
        self.assertIsInstance(Contacts.CNLabelDateAnniversary, str)

    @min_os_level("10.15")
    def testConstants10_15(self):
        self.assertIsInstance(Contacts.CNLabelSchool, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc
import Contacts


class TestContacts(TestCase):
    @min_os_level("10.11")
    def testClasses(self):
        self.assertIsInstance(Contacts.CNContact, objc.objc_class)


class TestCallableMetadata(TestCase):
    def test_callable_metadata_is_sane(self):
        self.assertCallableMetadataIsSane(Contacts)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Contacts


class TestCNContainer(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Contacts.CNContainerType)

    @min_os_level("10.11")
    def testConstants(self):
        self.assertEqual(Contacts.CNContainerTypeUnassigned, 0)
        self.assertEqual(Contacts.CNContainerTypeLocal, 1)
        self.assertEqual(Contacts.CNContainerTypeExchange, 2)
        self.assertEqual(Contacts.CNContainerTypeCardDAV, 3)

        self.assertIsInstance(Contacts.CNContainerIdentifierKey, str)
        self.assertIsInstance(Contacts.CNContainerNameKey, str)
        self.assertIsInstance(Contacts.CNContainerTypeKey, str)
